import { ref } from 'vue'
import request, { BASE_URL } from '@/utils/request'
import { Base64 } from 'js-base64'

export default function useNote() {
  const note = ref()

  const getNote = (user, path = '', repo = 'my-note') => {
    const { access_token } = user.token
    return request.get(`/api/v5/repos/${user.login}/${repo}/contents/${path}`, { params: { access_token } }).then(res => note.value = res)
  }

  const updateNote = (content, user) => {
    const { url, sha } = note.value
    const { access_token } = user.token
    const data = {
      access_token,
      content: Base64.encode(content),
      sha,
      message: new Date().toJSON(),
    }

    const filePath = url.replace(BASE_URL, '')

    return request.put(filePath, data).then(() => {
      // 获取最新的数据, 目的是更新 sha 值
      request.get(filePath, { params: { access_token } }).then(res => note.value = res)
    })
  }
  
  return {
    note,
    getNote,
    updateNote,
  }
}
