import { reactive } from 'vue'
import request from '@/utils/request'
import { getToken, setToken } from '@/utils/token'

export default function useUser() {
  const user = reactive({ token: getToken() })

  const signIn = (data) => {
    return request.post('/oauth/token', data, { contentType: 'application/x-www-form-urlencoded' }).then(res => {
      setToken(res)
      user.token = res
      if (user.token) {
        getUserInfo(user.token)
      }
    })
  }
  
  const signOut = () => {
    // xxx
  }

  const getUserInfo = (token) => {
    return request.get('/api/v5/user', { params: { access_token: token.access_token } }).then(res => {
      Object.assign(user, res || {})
    })
  }

  // 快过期的需要刷新 token
  const refreshToken = (token) => {
    const now = (new Date()).valueOf() / 1000
    const expire = token.expires_in + token.created_at
    const diff = 1 * 60 * 60 // 小时

    if (now + diff > expire) {
      return request.post('/oauth/token', null, { params: { grant_type: 'refresh_token', refresh_token: token.refresh_token } }).then(res => {
        setToken(res)
        user.token = res
      })
    }
  }
  
  const t = setTimeout(() => {
    clearTimeout(t)

    if (user.token) {
      refreshToken(user.token)
      // getUserInfo(user.token)
    }
  }, 0)

  return {
    user,
    signIn,
    signOut,
    getUserInfo
  }
}
