import axios from 'axios'
import router from '@/route';

export const BASE_URL = 'https://gitee.com'

const instance = axios.create({
  baseURL: BASE_URL
});

instance.interceptors.request.use((config) => {
  if (config.contentType) {
    config.headers = {
      ...config.headers || {},
      'Content-Type': config.contentType,
    }

    if (config.contentType === 'application/x-www-form-urlencoded') {
      config.data = transformQuerString(config.data)
    }
  } else {
    // 普通 data 转化为 formdata
    if (typeof config.data === 'object' && config.data) {
      config.data = Object.keys(config.data).reduce(((fm, k) => {
        fm.delete(k)
        fm.append(k, config.data[k])
        return fm
      }), new FormData())
    }
  }

  return config
})

instance.interceptors.response.use(function (response) {
  // Any status code that lie within the range of 2xx cause this function to trigger
  // Do something with response data
  return response.data || response;
}, function (error) {
  if (error && error.response) {
    if (error.response.status === 401) {
      router.push({ name: 'login' })
      return;
    }
  }


  // Any status codes that falls outside the range of 2xx cause this function to trigger
  // Do something with response error
  return Promise.reject(error);
});

function transformQuerString(params, encode = true) {
  if (encode) {
    return Object.keys(params).map(k => `${encodeURIComponent(k)}=${encodeURIComponent(params[k])}`).join('&')
  } else {
    return Object.keys(params).map(k => `${k}=${params[k]}`).join('&')
  }
}

export default instance
